﻿using System;
using System.Linq;
using System.Collections.ObjectModel;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;

using INT63DC_6CH.Controls;
using INT63DC_6CH.DialogForms;
using INT63DC_ImageDll;

namespace INT63DC_6CH.Forms
{
    public partial class FormCalibration : Form
    {
        #region Field
        private FormMain m_ParentForm;

        public bool IsInternalBalanceMode;

        private ControlCalibration6 Calibration6;
        private ControlCalibration7 Calibration7;
        private ControlCalibration8 Calibration8;
        private ControlCalibration10 Calibration10;
        private ControlCalibration12 Calibration12;
        #endregion

        #region Constructor
        public FormCalibration(FormMain parent)
        {
            InitializeComponent();

            this.ParentForm = parent;
        }
        #endregion

        #region Property
        public FormMain ParentForm
        {
            get { return this.m_ParentForm; }
            private set { this.m_ParentForm = value; }
        }
        #endregion

        #region Method
        private void InitializeDesign()
        {
            ImageDll images = new ImageDll();

            switch (this.ParentForm.SystemConfig.Language)
            {
                case DataStore.LanguageID.Korean:
                    break;
                case DataStore.LanguageID.English:
                    #region English
                    this.labelTitle.Text = "Calibration";
                    this.buttonStart.Text = "Start";
                    this.buttonBalance.Text = "Balance";
                    this.buttonCancel.Text = "Cancel";
                    this.groupBoxHelp.Text = "Help";

                    this.buttonBack.DisableImage = new Bitmap(images.GetImage(ImageDll.ButtonImages.engBackDisable));
                    this.buttonBack.DownImage = new Bitmap(images.GetImage(ImageDll.ButtonImages.engBackDown));
                    this.buttonBack.UpImage = new Bitmap(images.GetImage(ImageDll.ButtonImages.engBackUp));
                    #endregion
                    break;
                case DataStore.LanguageID.Chinese:
                    #region Chinese
                    this.labelTitle.Text = "校准";
                    this.buttonStart.Text = "开启";
                    this.buttonBalance.Text = "分銅";
                    this.buttonCancel.Text = "取消";
                    this.groupBoxHelp.Text = "帮助";

                    this.buttonBack.DisableImage = new Bitmap(images.GetImage(ImageDll.ButtonImages.chnBackDisable));
                    this.buttonBack.DownImage = new Bitmap(images.GetImage(ImageDll.ButtonImages.chnBackDown));
                    this.buttonBack.UpImage = new Bitmap(images.GetImage(ImageDll.ButtonImages.chnBackUp));

                    this.buttonStart.DisableImage = new Bitmap(images.GetImage(ImageDll.ButtonImages.chnFormCalibrationStartDisable));
                    this.buttonStart.DownImage = new Bitmap(images.GetImage(ImageDll.ButtonImages.chnFormCalibrationStartDown));
                    this.buttonStart.UpImage = new Bitmap(images.GetImage(ImageDll.ButtonImages.chnFormCalibrationStartUp));
                    this.buttonBalance.DisableImage = new Bitmap(images.GetImage(ImageDll.ButtonImages.chnFormCalibrationBalanceDisable));
                    this.buttonBalance.DownImage = new Bitmap(images.GetImage(ImageDll.ButtonImages.chnFormCalibrationBalanceDown));
                    this.buttonBalance.UpImage = new Bitmap(images.GetImage(ImageDll.ButtonImages.chnFormCalibrationBalanceUp));
                    this.buttonCancel.DisableImage = new Bitmap(images.GetImage(ImageDll.ButtonImages.chnFormCalibrationCancelDisable));
                    this.buttonCancel.DownImage = new Bitmap(images.GetImage(ImageDll.ButtonImages.chnFormCalibrationCancelDown));
                    this.buttonCancel.UpImage = new Bitmap(images.GetImage(ImageDll.ButtonImages.chnFormCalibrationCancelUp));
                    #endregion
                    break;
                case DataStore.LanguageID.Czech:
                    #region Czech
                    this.labelTitle.Text = "Kalibrace";
                    this.buttonStart.Text = "Start";
                    this.buttonBalance.Text = "Váha";
                    this.buttonCancel.Text = "Zrušit";
                    this.groupBoxHelp.Text = "Pomoc";

                    this.buttonBack.DisableImage = new Bitmap(images.GetImage(ImageDll.ButtonImages.czeBackDisable));
                    this.buttonBack.DownImage = new Bitmap(images.GetImage(ImageDll.ButtonImages.czeBackDown));
                    this.buttonBack.UpImage = new Bitmap(images.GetImage(ImageDll.ButtonImages.czeBackUp));
                    #endregion
                    break;
                case DataStore.LanguageID.German:
                    #region German
                    this.labelTitle.Text = "Kalibrierung";
                    this.buttonStart.Text = "Start";
                    this.buttonBalance.Text = "Gegengewicht";
                    this.buttonCancel.Text = "Stornieren";
                    this.groupBoxHelp.Text = "Hilfe";

                    this.buttonBack.DisableImage = new Bitmap(images.GetImage(ImageDll.ButtonImages.gerBackDisable));
                    this.buttonBack.DownImage = new Bitmap(images.GetImage(ImageDll.ButtonImages.gerBackDown));
                    this.buttonBack.UpImage = new Bitmap(images.GetImage(ImageDll.ButtonImages.gerBackUp));
                    #endregion
                    break;
                case DataStore.LanguageID.Japanese:
                    #region Japanese
                    this.labelTitle.Text = "校正";
                    this.buttonStart.Text = "スタㅡト";
                    this.buttonBalance.Text = "バランス";
                    this.buttonCancel.Text = "キャンセル";
                    this.groupBoxHelp.Text = "ヘルプ";

                    this.buttonBack.DisableImage = new Bitmap(images.GetImage(ImageDll.ButtonImages.jpnBackDisable));
                    this.buttonBack.DownImage = new Bitmap(images.GetImage(ImageDll.ButtonImages.jpnBackDown));
                    this.buttonBack.UpImage = new Bitmap(images.GetImage(ImageDll.ButtonImages.jpnBackUp));
                    #endregion
                    break;
                default:
                    break;
            }
        }
        private void InitializeControl()
        {
            this.IsInternalBalanceMode = false;
            this.buttonExtanalCAL.ButtonUp();

            switch (this.ParentForm.SystemConfig.EquipmentColumns)
            {
                case 6:
                    this.Calibration6 = new ControlCalibration6(this);
                    this.Calibration6.Location = new Point(0, 80);
                    this.Controls.Add(this.Calibration6);
                    break;
                case 7:
                    this.Calibration7 = new ControlCalibration7(this);
                    this.Calibration7.Location = new Point(0, 80);
                    this.Controls.Add(this.Calibration7);
                    break;
                case 8:
                    this.Calibration8 = new ControlCalibration8(this);
                    this.Calibration8.Location = new Point(0, 80);
                    this.Controls.Add(this.Calibration8);
                    break;
                case 10:
                    this.Calibration10 = new ControlCalibration10(this);
                    this.Calibration10.Location = new Point(0, 70);
                    this.Controls.Add(this.Calibration10);
                    break;
                case 12:
                    this.Calibration12 = new ControlCalibration12(this);
                    this.Calibration12.Location = new Point(0, 70);
                    this.Controls.Add(this.Calibration12);
                    break;
                default:
                    break;
            }

            this.UpdateDisplayHelpInit();
        }

        public void UpdateDisplayHelpInit()
        {
            this.listBoxHelp.ClearAll();

            switch (this.ParentForm.SystemConfig.Language)
            {
                case DataStore.LanguageID.Korean:
                    this.listBoxHelp.AddItem("중량조정");
                    this.listBoxHelp.AddItem("LANE을 선택 후");
                    this.listBoxHelp.AddItem("시작을 누르세요");
                    break;
                case DataStore.LanguageID.English:
                    this.listBoxHelp.AddItem("Calibration");
                    this.listBoxHelp.AddItem("After selecting lane, ");
                    this.listBoxHelp.AddItem("push the [Start] button.");
                    break;
                case DataStore.LanguageID.Chinese:
                    this.listBoxHelp.AddItem("校准");
                    this.listBoxHelp.AddItem("选择线后，按[开始]按钮。");
                    break;
                case DataStore.LanguageID.Czech:
                    this.listBoxHelp.AddItem("Kalibrace");
                    this.listBoxHelp.AddItem("Po výběru řádku, ");
                    this.listBoxHelp.AddItem("stiskněte tlačítko [Start].");
                    break;
                case DataStore.LanguageID.German:
                    this.listBoxHelp.AddItem("Kalibrierung");
                    this.listBoxHelp.AddItem("Drücken Sie nach der Auswahl der");
                    this.listBoxHelp.AddItem("Zeile die Taste [Start].");
                    break;
                case DataStore.LanguageID.Japanese:
                    this.listBoxHelp.AddItem("較正");
                    this.listBoxHelp.AddItem("レㅡンを選択したら、");
                    this.listBoxHelp.AddItem("［スタㅡト］ボタンを押します。");
                    break;
                default:
                    break;
            }
        }
        public void UpdateDisplayHelpBalance()
        {
            this.listBoxHelp.ClearAll();

            switch (this.ParentForm.SystemConfig.Language)
            {
                case DataStore.LanguageID.Korean:
                    this.listBoxHelp.AddItem("분동 계산중 입니다");
                    this.listBoxHelp.AddItem("잠시만 기다리세요");
                    break;
                case DataStore.LanguageID.English:
                    this.listBoxHelp.AddItem("Caculating...");
                    this.listBoxHelp.AddItem("Wait a minute.");
                    break;
                case DataStore.LanguageID.Chinese:
                    this.listBoxHelp.AddItem("计算...");
                    this.listBoxHelp.AddItem("请稍等");
                    break;
                case DataStore.LanguageID.Czech:
                    this.listBoxHelp.AddItem("Kontroluji hmotnost...");
                    this.listBoxHelp.AddItem("čekejte prosím.");
                    break;
                case DataStore.LanguageID.German:
                    this.listBoxHelp.AddItem("Gewichtsüberprüfung,");
                    this.listBoxHelp.AddItem("bitte warten");
                    break;
                case DataStore.LanguageID.Japanese:
                    this.listBoxHelp.AddItem("重量をチェック。");
                    this.listBoxHelp.AddItem("待機する");
                    break;
                default:
                    break;
            }
        }
        public void UpdateDisplayHelpStart()
        {
            this.listBoxHelp.ClearAll();

            switch (this.ParentForm.SystemConfig.Language)
            {
                case DataStore.LanguageID.Korean:
                    this.listBoxHelp.AddItem("중량조정을 시작합니다.");
                    this.listBoxHelp.AddItem("잠시만 기다리세요.");
                    break;
                case DataStore.LanguageID.English:
                    this.listBoxHelp.AddItem("Calibration start.");
                    this.listBoxHelp.AddItem("Wait a minute.");
                    break;
                case DataStore.LanguageID.Chinese:
                    this.listBoxHelp.AddItem("校准开始按钮");
                    this.listBoxHelp.AddItem("请稍等");
                    break;
                case DataStore.LanguageID.Czech:
                    this.listBoxHelp.AddItem("START kalibrace");
                    this.listBoxHelp.AddItem("čekejte prosím.");
                    break;
                case DataStore.LanguageID.German:
                    this.listBoxHelp.AddItem("Kalibrierungsstart");
                    this.listBoxHelp.AddItem("bitte warten");
                    break;
                case DataStore.LanguageID.Japanese:
                    this.listBoxHelp.AddItem("校正開始");
                    this.listBoxHelp.AddItem("待機する");
                    break;
                default:
                    break;
            }
        }
        public void UpdateDisplayHelpCancel()
        {
            this.listBoxHelp.ClearAll();

            switch (this.ParentForm.SystemConfig.Language)
            {
                case DataStore.LanguageID.Korean:
                    this.listBoxHelp.AddItem("중량조정을 취소합니다");
                    break;
                case DataStore.LanguageID.English:
                    this.listBoxHelp.AddItem("Cancel the Calibration");
                    break;
                case DataStore.LanguageID.Chinese:
                    this.listBoxHelp.AddItem("取消校准");
                    break;
                case DataStore.LanguageID.Czech:
                    this.listBoxHelp.AddItem("Zrušení Kalibrace");
                    break;
                case DataStore.LanguageID.German:
                    this.listBoxHelp.AddItem("Brechen Sie die ");
                    this.listBoxHelp.AddItem("Kalibrierung ab");
                    break;
                case DataStore.LanguageID.Japanese:
                    this.listBoxHelp.AddItem("校正をキャンセルする");
                    break;
                default:
                    break;
            }
        }
        public void UpdateDisplayHelpCalStandby()
        {
            this.listBoxHelp.ClearAll();

            switch (this.ParentForm.SystemConfig.Language)
            {
                case DataStore.LanguageID.Korean:
                    this.listBoxHelp.AddItem("분동을 올려주세요.");
                    break;
                case DataStore.LanguageID.English:
                    this.listBoxHelp.AddItem("Put the balance weight.");
                    break;
                case DataStore.LanguageID.Chinese:
                    this.listBoxHelp.AddItem("放平衡重");
                    break;
                case DataStore.LanguageID.Czech:
                    this.listBoxHelp.AddItem("Položit vyvážení hmotnosti.");
                    break;
                case DataStore.LanguageID.German:
                    this.listBoxHelp.AddItem("Gewicht auf den Förderer legen");
                    break;
                case DataStore.LanguageID.Japanese:
                    this.listBoxHelp.AddItem("バランスウェイトを置く。");
                    break;
                default:
                    break;
            }
        }
        public void UpdateDisplayHelpCalFinish()
        {
            this.listBoxHelp.ClearAll();

            switch (this.ParentForm.SystemConfig.Language)
            {
                case DataStore.LanguageID.Korean:
                    this.listBoxHelp.AddItem("중량조정이 완료 되었습니다.");
                    break;
                case DataStore.LanguageID.English:
                    this.listBoxHelp.AddItem("Finished.");
                    break;
                case DataStore.LanguageID.Chinese:
                    this.listBoxHelp.AddItem("完");
                    break;
                case DataStore.LanguageID.Czech:
                    this.listBoxHelp.AddItem("Ukončený.");
                    break;
                case DataStore.LanguageID.German:
                    this.listBoxHelp.AddItem("Die Kalibrierung ist abgeschlossen.");
                    break;
                case DataStore.LanguageID.Japanese:
                    this.listBoxHelp.AddItem("校正終了");
                    break;
                default:
                    break;
            }
        }
        public void UpdateDisplayHelpCalError()
        {
            this.listBoxHelp.ClearAll();

            switch (this.ParentForm.SystemConfig.Language)
            {
                case DataStore.LanguageID.Korean:
                    this.listBoxHelp.AddItem("중량조정 에러");
                    this.listBoxHelp.AddItem("다시 시도해 주세요");
                    break;
                case DataStore.LanguageID.English:
                    this.listBoxHelp.AddItem("Calibration error.");
                    this.listBoxHelp.AddItem("Please try again.");
                    break;
                case DataStore.LanguageID.Chinese:
                    this.listBoxHelp.AddItem("错误发生，重试");
                    break;
                case DataStore.LanguageID.Czech:
                    this.listBoxHelp.AddItem("Kalibrace chyba.");
                    this.listBoxHelp.AddItem("Zkuste znovu.");
                    break;
                case DataStore.LanguageID.German:
                    this.listBoxHelp.AddItem("Fehler!");
                    this.listBoxHelp.AddItem("Bitte noch einmal versuchen");
                    break;
                case DataStore.LanguageID.Japanese:
                    this.listBoxHelp.AddItem("校正エラㅡ");
                    this.listBoxHelp.AddItem("もうㅡ度試してください");
                    break;
                default:
                    break;
            }
        }
        public void UpdateDisplayHelpRemoveBalance()
        {
            this.listBoxHelp.ClearAll();

            switch (this.ParentForm.SystemConfig.Language)
            {
                case DataStore.LanguageID.Korean:
                    this.listBoxHelp.AddItem("분동을 제거해 주세요");
                    break;
                case DataStore.LanguageID.English:
                    this.listBoxHelp.AddItem("Remove the balance");
                    break;
                case DataStore.LanguageID.Chinese:
                    this.listBoxHelp.AddItem("移除平衡");
                    break;
                case DataStore.LanguageID.Czech:
                    this.listBoxHelp.AddItem("Odstranění vyvážení");
                    break;
                case DataStore.LanguageID.German:
                    this.listBoxHelp.AddItem("Balance entfernen");
                    break;
                case DataStore.LanguageID.Japanese:
                    this.listBoxHelp.AddItem("バランスを外す");
                    break;
                default:
                    break;
            }
        }

        public void CalibrationButtonEnable(bool btStart, bool btBalance, bool btCcancel)
        {
            if (this.buttonStart.Enabled != btStart)
                this.buttonStart.Enabled = btStart;
            if (this.buttonBalance.Enabled != btBalance)
                this.buttonBalance.Enabled = btBalance;
            if (this.buttonCancel.Enabled != btCcancel)
                this.buttonCancel.Enabled = btCcancel;
        }
        public void UpdateWeightDisplay(DataStore.EquipmentStatus status, Collection<WeightData> weightDatas)
        {
            switch (this.ParentForm.SystemConfig.EquipmentColumns)
            {
                case 6:
                    this.Calibration6.UpdateWeightDisplay(status, weightDatas);
                    break;
                case 7:
                    this.Calibration7.UpdateWeightDisplay(status, weightDatas);
                    break;
                case 8:
                    this.Calibration8.UpdateWeightDisplay(status, weightDatas);
                    break;
                case 10:
                    this.Calibration10.UpdateWeightDisplay(status, weightDatas);
                    break;
                case 12:
                    this.Calibration12.UpdateWeightDisplay(status, weightDatas);
                    break;
                default:
                    break;
            }
        }

        public void DisplayRefresh()
        {
            this.ParentForm.SystemConfig.CurrentForm = DataStore.FormStore.FormCalibration;
            this.ParentForm.TransferData(CommunicationCommand.ModeCalibration, CommunicationID.MainBoard);

            this.buttonExtanalCAL.ButtonUp();
            this.buttonExtanalCAL.Text = "내부 분동 CAL";
            this.IsInternalBalanceMode = true;

            switch (this.ParentForm.SystemConfig.EquipmentColumns)
            {
                case 6:
                    if (this.Calibration6 != null)
                        this.Calibration6.DisplayRefresh();
                    break;
                case 7:
                    if (this.Calibration7 != null)
                        this.Calibration7.DisplayRefresh();
                    break;
                case 8:
                    if (this.Calibration8 != null)
                        this.Calibration8.DisplayRefresh();
                    break;
                case 10:
                    if (this.Calibration10 != null)
                        this.Calibration10.DisplayRefresh();
                    break;
                case 12:
                    if (this.Calibration12 != null)
                        this.Calibration12.DisplayRefresh();
                    break;
                default:
                    break;
            }

            this.CalibrationButtonEnable(false, false, false);
            this.UpdateDisplayHelpInit();
        }
        #endregion

        #region Override Member
        protected override void OnLoad(EventArgs e)
        {
            base.OnLoad(e);

            this.InitializeDesign();
            this.InitializeControl();
        }
        #endregion

        #region Event Handler
        private void buttonStart_Click(object sender, EventArgs e)
        {
            switch (this.ParentForm.SystemConfig.EquipmentColumns)
            {
                case 6:
                    this.Calibration6.CalibrationStart(this.IsInternalBalanceMode);
                    break;
                case 7:
                    this.Calibration7.CalibrationStart(this.IsInternalBalanceMode);
                    break;
                case 8:
                    this.Calibration8.CalibrationStart(this.IsInternalBalanceMode);
                    break;
                case 10:
                    this.Calibration10.CalibrationStart(this.IsInternalBalanceMode);
                    break;
                case 12:
                    this.Calibration12.CalibrationStart(this.IsInternalBalanceMode);
                    break;
                default:
                    break;
            }
        }
        private void buttonBalance_Click(object sender, EventArgs e)
        {
            switch (this.ParentForm.SystemConfig.EquipmentColumns)
            {
                case 6:
                    this.Calibration6.CalibrationBalance();
                    break;
                case 7:
                    this.Calibration7.CalibrationBalance();
                    break;
                case 8:
                    this.Calibration8.CalibrationBalance();
                    break;
                case 10:
                    this.Calibration10.CalibrationBalance();
                    break;
                case 12:
                    this.Calibration12.CalibrationBalance();
                    break;
                default:
                    break;
            }
        }
        private void buttonCancel_Click(object sender, EventArgs e)
        {
            switch (this.ParentForm.SystemConfig.EquipmentColumns)
            {
                case 6:
                    this.Calibration6.CalibrationCancel();
                    break;
                case 7:
                    this.Calibration7.CalibrationCancel();
                    break;
                case 8:
                    this.Calibration8.CalibrationCancel();
                    break;
                case 10:
                    this.Calibration10.CalibrationCancel();
                    break;
                case 12:
                    this.Calibration12.CalibrationCancel();
                    break;
                default:
                    break;
            }
        }
        private void buttonBack_Click(object sender, EventArgs e)
        {
            switch (this.ParentForm.SystemConfig.EquipmentColumns)
            {
                case 6:
                    this.Calibration6.CalibrationCancel();
                    break;
                case 7:
                    this.Calibration7.CalibrationCancel();
                    break;
                case 8:
                    this.Calibration8.CalibrationCancel();
                    break;
                case 10:
                    this.Calibration10.CalibrationCancel();
                    break;
                case 12:
                    this.Calibration12.CalibrationCancel();
                    break;
                default:
                    break;
            }

            this.ParentForm.ChildFormMenu.DisplayRefresh();
            ((FormMain)(Owner)).smartForm.Show((int)DataStore.FormStore.FormMenu);
        }
        private void buttonExtanalCAL_Click(object sender, EventArgs e)
        {
            if (this.buttonExtanalCAL.ButtonStatus == SmartX.SmartButton.BUTSTATUS.DOWN)
            {
                this.buttonExtanalCAL.Text = "외부 분동 CAL";
                this.IsInternalBalanceMode = false;
            }
            else
            {
                this.buttonExtanalCAL.Text = "내부 분동 CAL";
                this.IsInternalBalanceMode = true;
            }
        }
        private void buttonZero_Click(object sender, EventArgs e)
        {
            this.ParentForm.TransferData(CommunicationCommand.Zero, CommunicationID.SubBoardAll);

            // SetTrackingHistoryData
            this.ParentForm.SetTrackingHistoryData(DataStore.TrackingOperation.Zero, "");
        }
        #endregion
    }
}